@@ -426,7 +426,7 @@ bugzilla_parse_response (SoupMessage *msg, GError **err)
 	else {
 		g_value_unset (&value);
 		g_set_error (err, BUGZILLA_ERROR, BUGZILLA_ERROR_RECV_PARSE_FAILED, 
-			     _("Unable to parse XML-RPC Response\n\n%s"),
+			     _("Unable to parse XML-RPC response\n\n%s"),
 			     msg->response_body->data);
 		return NULL;
 	}
@@ -438,7 +438,7 @@ bugzilla_parse_response (SoupMessage *msg, GError **err)
 SoupMessage*
 bugzilla_create_report (BugzillaApplication *app, int type, GnomeVersionInfo *gnome_version,
 		        const char *username, const char *title, const char *text,
-		        GtkBuilder *ui, const char *minidump_file, GError **err)
+		        GtkBuilder *ui, GError **err)
 {
 	SoupMessage *message;
 	const char *uri;
@@ -505,53 +505,7 @@ bugzilla_create_report (BugzillaApplication *app, int type, GnomeVersionInfo *gn
 	soup_value_hash_insert (report, "comment", G_TYPE_STRING, rv->str);
     	g_string_free (rv, TRUE);
 
-	if (minidump_file) {
-		gchar *minidumpbuf;
-		gsize length;
-		GError *error = NULL;
-		gchar *base64 = NULL;
-
-		if (g_file_get_contents (minidump_file, &minidumpbuf, &length, &error)) {
-			base64 = g_base64_encode ((guchar*)minidumpbuf, length);
-			g_free (minidumpbuf);
-		} else {
-			g_error_free (error);
-		}
-
-		if (base64) {	
-			gchar *basename;
-			gchar *id;
-			GByteArray *ba;
-
-			basename = g_path_get_basename (minidump_file);
-			id = g_strndup (basename, strlen (basename) - strlen (".dmp"));
-			
-			soup_value_hash_insert (report, "minidump-id",
-						G_TYPE_STRING, id);
-
-			/* FIXME: This is broken; for some reason
-			 * bug-buddy is base64-encoding the minidump
-			 * *twice*. (Once itself, and once by asking
-			 * libsoup to do it.) Fix this after verifying
-			 * that the server side can deal with the
-			 * fix...
-			 */
-			ba = g_byte_array_sized_new (strlen (base64));
-			g_byte_array_append (ba, (guchar *)base64, strlen (base64));
-			soup_value_hash_insert (report, "minidump",
-						SOUP_TYPE_BYTE_ARRAY, ba);
-			g_byte_array_free (ba, TRUE);
-			g_free (base64);
-			g_free (basename);
-			g_free (id);
-		}
-	}
-
-	if (minidump_file)
-		//uri = "http://localhost/breakpad/xmlrpc.py";
-		uri = "http://socorro.gnome.org/collect.py";
-	else 
-		uri = "http://bugzilla.gnome.org/bugbuddy.cgi";
+	uri = "http://bugzilla.gnome.org/bugbuddy.cgi";
 
 	message = soup_xmlrpc_request_new (uri, "BugBuddy.createBug",
 					   G_TYPE_HASH_TABLE, report,
